@@ -4,8 +4,9 @@ it is used for the setup.py
 """
 # Version of the url2srt package
 
-__version__ = "1.0.4"
+__version__ = "1.0.5"
 
+import sys
 import argparse
 from ardicsrtcollector.youtube_srt_mp3 import YoutubeSrtMp3
 
@@ -35,4 +36,4 @@ def get_all_srt_mp3_files():
 
 
 if __name__ == '__main__':
-    get_all_srt_mp3_files()
+    sys.exit(get_all_srt_mp3_files())
